@@ -3,6 +3,6 @@ package MyApp1::Schema::ResultSet::CD;
 use strict;
 use warnings;
 
-use parent 'DBIx::Class::ResultSet';
+use base 'DBIx::Class::ResultSet';
 
 1; # eof
\ No newline at end of file
